@@ -22,15 +22,9 @@ plot_precision_recall <- function(x, display_cutpoint = TRUE, ...) {
 
     if (!(has_column(x, "subgroup"))) {
         dts_pr <- "roc_curve"
-        fll <- NULL
-        clr <- NULL
-        clr_pr <- NULL
         transparency <- 1
     } else {
         dts_pr <- c("roc_curve", "subgroup")
-        fll <- "subgroup"
-        clr <- "subgroup"
-        clr_pr <- ~ subgroup
         transparency <- 0.6
     }
 
@@ -41,29 +35,35 @@ plot_precision_recall <- function(x, display_cutpoint = TRUE, ...) {
     }
     for (r in 1:nrow(x)) {
         x$roc_curve[[r]] <- x$roc_curve[[r]] %>%
-            dplyr::mutate_(Precision = ~ tp / (tp + fp),
-                           Recall = ~ tp / (tp + fn))
+            dplyr::mutate(Precision = tp / (tp + fp),
+                           Recall = tp / (tp + fn))
     }
     if (display_cutpoint) {
-        optcut_coords <- apply(x, 1, function(r) {
-            opt_ind <- get_opt_ind(roc_curve = r$roc_curve,
-                                   oc = r$optimal_cutpoint,
-                                   direction = r$direction)
-            data.frame(Precision = r$roc_curve$Precision[opt_ind],
-                       Recall = r$roc_curve$Recall[opt_ind])
+        optcut_coords <- purrr::pmap_df(x, function(...) {
+            args <- list(...)
+            opt_ind <- get_opt_ind(roc_curve = args$roc_curve,
+                                   oc = args$optimal_cutpoint,
+                                   direction = args$direction)
+            data.frame(Precision = args$roc_curve$Precision[opt_ind],
+                       Recall = args$roc_curve$Recall[opt_ind])
+
         })
-        optcut_coords <- do.call(rbind, optcut_coords)
     }
     res_unnested <- x %>%
-        dplyr::select_(.dots = dts_pr) %>%
-        tidyr::unnest_(unnest_cols = "roc_curve")
+        dplyr::select(dts_pr) %>%
+        tidyr::unnest(.data$roc_curve)
     res_unnested <- res_unnested[is.finite(res_unnested$x.sorted), ]
-    pr <- ggplot2::ggplot(res_unnested,
-                          ggplot2::aes_(x = ~ Recall, y = ~ Precision, color = clr_pr)) +
+    if (!(has_column(x, "subgroup"))) {
+        pr <- ggplot2::ggplot(res_unnested,
+                              ggplot2::aes(x = Recall, y = Precision))
+    } else {
+        pr <- ggplot2::ggplot(res_unnested,
+                              ggplot2::aes(x = Recall, y = Precision,
+                                           color = subgroup))
+    }
+    pr <- pr +
         ggplot2::geom_line() +
         plot_title +
-        ggplot2::xlab("Recall") +
-        ggplot2::ylab("Precision") +
         ggplot2::theme(aspect.ratio = 1) +
         ggplot2::coord_cartesian(xlim = c(0, 1), ylim = c(0, 1))
     if (display_cutpoint) {
